Welcome to DivBrowse's documentation!
=====================================

.. image:: https://readthedocs.org/projects/divbrowse/badge/?version=latest
   :target: https://divbrowse.readthedocs.io/?badge=latest
   :alt: Documentation Status

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction.rst
   installation.rst
   usage.rst
   javascript_api.rst
   tutorial.rst
   configuration.rst
   API Reference <../autoapi#http://>


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
